# import cv2
import time
from ddcmaker import PWMServo
# import LSC_Client

from ddcmaker import LSC_Client

import threading

from inspect import signature
from functools import wraps


def typeassert(*type_args, **type_kwargs):
    def decorate(func):
        sig = signature(func)
        bound_types = sig.bind_partial(*type_args, **type_kwargs).arguments

        @wraps(func)
        def wrapper(*args, **kwargs):
            bound_values = sig.bind(*args, **kwargs)
            for name, value in bound_values.arguments.items():
                if name in bound_types:
                    if not isinstance(value, bound_types[name]):
                        raise TypeError('Argument {} must be {}'.format(name, bound_types[name]))
            return func(*args, **kwargs)

        return wrapper

    return decorate


lsc = LSC_Client.LSC_Client()


class robot(object):
    lsc.MoveServo(6, 1500, 1000)
    lsc.MoveServo(7, 1500, 1000)
    time.sleep(2.1)

    def up(self, step=1):
        lsc.RunActionGroup(0, step)
        # lsc.WaitForFinish(5000)
        time.sleep(2)
        print("机器人站立")

    def down(self, step=1):
        lsc.RunActionGroup(14, step)
        # lsc.WaitForFinish(5000)
        time.sleep(2)
        print("机器人蹲下")

    def check(self, step=1):
        lsc.RunActionGroup(188, step)
        # lsc.WaitForFinish(5000)
        time.sleep(2)
        print("机器人自检")

    def forward(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(1, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("机器人前进")

    def backward(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(2, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("机器人后退")

    def left(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(3, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("<---机器人左转")

    def right(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(4, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("机器人右转--->")

    # def circle(self, step, radius):
    #     #     for j in range(0, step):
    #     #         for i in range(0, 10):
    #     #             self.right(2)
    #     #             self.forward(radius)
    #     #     self.up(1)
    # =====================================================
    # def shaking_head(self, step):
    #     for i in range(step):
    #         lsc.RunActionGroup(50, 1)
    #         lsc.WaitForFinish(5000)
    #         print("机器人摇头")

    # def nod(self, step):
    #     for i in range(step):
    #         lsc.RunActionGroup(51, 1)
    #         lsc.WaitForFinish(5000)
    #         print("机器人点头")

    def nod(self, step=1):
        for i in range(step):
            PWMServo.setServo(1, 1800, 200)
            time.sleep(0.3)
            PWMServo.setServo(1, 1200, 200)
            time.sleep(0.3)
            PWMServo.setServo(1, 1500, 100)
            time.sleep(1)
            print("机器人点头")

    def shaking_head(self, step=1):
        for i in range(step):
            PWMServo.setServo(2, 1800, 200)
            time.sleep(0.4)
            PWMServo.setServo(2, 1200, 200)
            time.sleep(0.4)
            PWMServo.setServo(2, 1500, 100)
            time.sleep(1)
            print("机器人摇头")

    '''这里的动作组不再是点头摇头了，需要重新写'''
    # =======================================================
    def left_slide(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(11, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("<<<*****机器人左滑")

    def right_slide(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(12, 1)
            # lsc.WaitForFinish(5000)
            time.sleep(2)
            print("机器人右滑******>>>")

    def push_up(self, step=1):
        lsc.RunActionGroup(7, step)
        time.sleep(3)
        print("机器人俯卧撑")

    def abdominal_curl(self, step=1):
        lsc.RunActionGroup(8, step)
        time.sleep(3)
        print("机器人仰卧起坐")

    def wave(self, step=1):
        for i in range(step):
            lsc.RunActionGroup(9, 1)
            time.sleep(2.1)
            print("机器人挥手┏(＾0＾)┛")

    def bow(self, step=1):
        lsc.RunActionGroup(10, step)
        time.sleep(2.1)
        print("机器人鞠躬╰(￣▽￣)╭")

    def spread_wings(self, step=1):
        lsc.RunActionGroup(13, step)
        time.sleep(3)
        print("机器人大鹏展翅")

    def haha(self,step=1):
        lsc.RunActionGroup(15, step)
        time.sleep(2.1)
        print("机器人哈哈大笑o(*￣▽￣*)o")

    def left_bending_hook(self, step=1):
        lsc.RunActionGroup(30, step)
        time.sleep(4)
        print("机器人直拳三连击")

    def right_bending_hook(self, step=1):
        lsc.RunActionGroup(31, step)
        time.sleep(3)
        print("机器人下勾拳连击")

    def left_hook(self, step=1):
        lsc.RunActionGroup(32, step)
        time.sleep(2)
        print("机器人左勾拳")

    def right_hook(self, step=1):
        lsc.RunActionGroup(33, step)
        time.sleep(2)
        print("机器人右勾拳")

    def punching(self, step=1):
        lsc.RunActionGroup(34, step)
        time.sleep(2)
        print("机器人攻步冲拳")

    def crouching(self, step=1):
        lsc.RunActionGroup(35, step)
        time.sleep(3)
        print("机器人八字蹲拳")

    def yongchun(self, step=1):
        lsc.RunActionGroup(36, step)
        time.sleep(3)
        print("机器人咏春拳")

    def beat_chest(self, step=1):
        lsc.RunActionGroup(37, step)
        time.sleep(2)
        print("机器人捶胸")

    def left_side_kick(self, step=1):
        lsc.RunActionGroup(50, step)
        time.sleep(2)
        print("机器人左侧踢")

    def right_side_kick(self, step=1):
        lsc.RunActionGroup(51, step)
        time.sleep(2)
        print("机器人右侧踢")

    def left_foot_shot(self, step=1):
        lsc.RunActionGroup(52, step)
        time.sleep(2)
        print("机器人左脚射门")

    def right_foot_shot(self, step=1):
        lsc.RunActionGroup(53, step)
        time.sleep(2)
        print("机器人右脚射门")

    def show_poss(self, step=1):
        print("机器人摆拍poss")
        lsc.RunActionGroup(60, step)
        time.sleep(15)

    def inverted_standing(self, step=1):
        lsc.RunActionGroup(101, step)
        time.sleep(5)
        print("机器人前倒站立")

    def rear_stand_up(self, step=1):
        lsc.RunActionGroup(102, step)
        time.sleep(5)
        print("机器人后倒站立")


'''
你好呀，为什么要打开这个文件
'''
